@@ -1,4 +1,4 @@
-__version__ = '1.0.31'
+__version__ = '1.0.32'
 __author__ = 'arnold'
 
 import json
@@ -122,3 +122,5 @@ class TerraformQueryExtension(Extension):
                     return output["attributes"]["value"]
                 else:
                     sys.exit("Value is None for attribute " +name)
+            else:
+                sys.exit("Invalid attribute " +name)
